METHODS = [
    'test', 'key_get', 'key_set', 'key_list', 'key_list_all',
    'key_get_recursive', 'key_copy', 'key_rename', 'key_exists', 'key_explain',
    'key_delete', 'key_delete_recursive', 'purge', 'check', 'repair', 'info',
    'key_dump', 'key_load', 'key_update', 'safe_purge', 'purge_cache',
    'server_set', 'key_increment', 'key_decrement', 'key_get_field',
    'key_set_field', 'key_delete_field'
]

DEFAULT_SERVER_PORT = 8870
